@@ -307,18 +307,18 @@ impl<'a> Default for SamplerDescriptor<'a> {
     fn default() -> Self {
         Self {
             name: "",
-            mag_filter: vk::Filter::LINEAR,
-            min_filter: vk::Filter::LINEAR,
-            mipmap_mode: vk::SamplerMipmapMode::LINEAR,
-            address_mode_u: vk::SamplerAddressMode::CLAMP_TO_EDGE,
-            address_mode_v: vk::SamplerAddressMode::CLAMP_TO_EDGE,
-            address_mode_w: vk::SamplerAddressMode::CLAMP_TO_EDGE,
-            mip_lod_bias: vk::SamplerMipmapMode::LINEAR,
+            mag_filter: vk::Filter::NEAREST,
+            min_filter: vk::Filter::NEAREST,
+            mipmap_mode: vk::SamplerMipmapMode::NEAREST,
+            address_mode_u: vk::SamplerAddressMode::REPEAT,
+            address_mode_v: vk::SamplerAddressMode::REPEAT,
+            address_mode_w: vk::SamplerAddressMode::REPEAT,
+            mip_lod_bias: vk::SamplerMipmapMode::NEAREST,
             anisotropy_enable: false,
             max_anisotropy: 0.0,
-            compare_op: Some(vk::CompareOp::LESS_OR_EQUAL),
+            compare_op: Some(vk::CompareOp::NEVER),
             min_lod: 0.0,
-            max_lod: std::f32::MAX,
+            max_lod: f32::MAX,
             border_color: None,
             unnormalized_coordinates: false,
             flags: None,
